Documentation
¶
Overview ¶
Package cmd is the entrypoint to cli
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewBrevCommand ¶
func NewDefaultBrevCommand ¶
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package agentskill handles installation of the Brev CLI agent skill
|
Package agentskill handles installation of the Brev CLI agent skill |
|
Deprecated: This package is superseded by pkg/cmd/gpucreate which is the registered "brev create" command.
|
Deprecated: This package is superseded by pkg/cmd/gpucreate which is the registered "brev create" command. |
|
Package deregister provides the brev deregister command for device deregistration
|
Package deregister provides the brev deregister command for device deregistration |
|
Package enablessh provides the brev enableSSH command for enabling SSH access to a registered external node.
|
Package enablessh provides the brev enableSSH command for enabling SSH access to a registered external node. |
|
Package gpucreate provides a command to create GPU instances with retry logic
|
Package gpucreate provides a command to create GPU instances with retry logic |
|
Package gpusearch provides a command to search and filter GPU instance types
|
Package gpusearch provides a command to search and filter GPU instance types |
|
Package grantssh provides the brev grant-ssh command for granting SSH access to a registered device for another org member.
|
Package grantssh provides the brev grant-ssh command for granting SSH access to a registered device for another org member. |
|
Package healthcheck checks the health of the backend
|
Package healthcheck checks the health of the backend |
|
Package invite is for inviting
|
Package invite is for inviting |
|
Package login is for the get command
|
Package login is for the get command |
|
Package logout is for the logout command
|
Package logout is for the logout command |
|
Package ls lists workspaces in the current org
|
Package ls lists workspaces in the current org |
|
Package ollama is for starting AI/ML model workspaces
|
Package ollama is for starting AI/ML model workspaces |
|
Package recreate is for the recreate command
|
Package recreate is for the recreate command |
|
Package refresh lists workspaces in the current org
|
Package refresh lists workspaces in the current org |
|
Package register provides the brev register command for device registration
|
Package register provides the brev register command for device registration |
|
Package revokessh provides the brev revoke-ssh command for revoking SSH access to a registered device by calling the backend API.
|
Package revokessh provides the brev revoke-ssh command for revoking SSH access to a registered device by calling the backend API. |
|
Package set is for the set command
|
Package set is for the set command |
|
Package sshkeys gets your public ssh key to add to github/gitlab
|
Package sshkeys gets your public ssh key to add to github/gitlab |
|
Package start is for starting Brev workspaces
|
Package start is for starting Brev workspaces |
|
Package stop is for stopping Brev workspaces
|
Package stop is for stopping Brev workspaces |
|
Package upgrade provides the brev upgrade command.
|
Package upgrade provides the brev upgrade command. |
Click to show internal directories.
Click to hide internal directories.