helpers

package
v0.6.321 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 14, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ResolveNodeByName

func ResolveNodeByName(ctx context.Context, nodeClient devplaneapiv1connect.ExternalNodeServiceClient, orgID string, nodeName string) (*nodev1.ExternalNode, error)

ResolveNodeByName returns the full node for the organization that matches the given name (case-insensitive). Use in non-interactive flows when the node is specified by name (e.g. --node my-node).

func ResolveOrgByName

func ResolveOrgByName(getter OrganizationGetter, orgName string) (*entity.Organization, error)

ResolveOrgByName returns the single organization matching the given name.

func SelectOrganizationInteractive

func SelectOrganizationInteractive(t *terminal.Terminal, organizations []entity.Organization, selector terminal.Selector) (*entity.Organization, error)

SelectOrganizationInteractive prompts the user to select an organization from the list.

Types

type OrganizationGetter

type OrganizationGetter interface {
	GetOrganizationsByName(name string) ([]entity.Organization, error)
}

Jump to