Documentation
¶
Overview ¶
Package grantssh provides the brev grant-ssh command for granting SSH access to a registered device for another org member.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewCmdGrantSSH ¶
func NewCmdGrantSSH(t *terminal.Terminal, store GrantSSHStore) *cobra.Command
Types ¶
type GrantSSHStore ¶
type GrantSSHStore interface {
GetCurrentUser() (*entity.User, error)
GetActiveOrganizationOrDefault() (*entity.Organization, error)
GetOrganizationsByName(name string) ([]entity.Organization, error)
ListOrganizations() ([]entity.Organization, error)
GetAccessToken() (string, error)
GetOrgRoleAttachments(orgID string) ([]entity.OrgRoleAttachment, error)
GetUserByID(userID string) (*entity.User, error)
}
GrantSSHStore defines the store methods needed by the grant-ssh command.
Click to show internal directories.
Click to hide internal directories.