Documentation
¶
Index ¶
- func ResolveNodeByName(ctx context.Context, nodeClient devplaneapiv1connect.ExternalNodeServiceClient, ...) (*nodev1.ExternalNode, error)
- func ResolveOrgByName(getter OrganizationGetter, orgName string) (*entity.Organization, error)
- func SelectOrganizationInteractive(t *terminal.Terminal, organizations []entity.Organization, ...) (*entity.Organization, error)
- type OrganizationGetter
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ResolveNodeByName ¶
func ResolveNodeByName(ctx context.Context, nodeClient devplaneapiv1connect.ExternalNodeServiceClient, orgID string, nodeName string) (*nodev1.ExternalNode, error)
ResolveNodeByName returns the full node for the organization that matches the given name (case-insensitive). Use in non-interactive flows when the node is specified by name (e.g. --node my-node).
func ResolveOrgByName ¶
func ResolveOrgByName(getter OrganizationGetter, orgName string) (*entity.Organization, error)
ResolveOrgByName returns the single organization matching the given name.
func SelectOrganizationInteractive ¶
func SelectOrganizationInteractive(t *terminal.Terminal, organizations []entity.Organization, selector terminal.Selector) (*entity.Organization, error)
SelectOrganizationInteractive prompts the user to select an organization from the list.
Types ¶
type OrganizationGetter ¶
type OrganizationGetter interface {
GetOrganizationsByName(name string) ([]entity.Organization, error)
}
Click to show internal directories.
Click to hide internal directories.